@@ -21,15 +21,14 @@ class AmqMqtt_Bridge():
             # feed a new message out, This message is come from amq
             new_payload = g_amq.fetch_message_payload(self.amq_queue_name)
             if new_payload is not None:
-                print("new_payload=", new_payload)
+                print("AmqMqtt_Bridge::spin_once()  topic= " + self.mqtt_topic_feed + "   payload= " + new_payload)
                 g_mqtt.publish(self.mqtt_topic_feed, new_payload)
                 self.amq_payload = new_payload
 
 
 class AmqMqtt_Bridges():
     def __init__(self) -> None:
-        self.all_bridges = [AmqMqtt_Bridge('test','test')]
-
+        self.all_bridges = []
 
     def Append(self, amq_queue_name:str):
         '''
@@ -51,9 +50,9 @@ if __name__ == '__main__':
     print("connected to mqtt broker.......")
 
     a = AmqMqtt_Bridges()
-    a.Append('twh_221109_gcode','twh/221109/gcode')
+    a.Append('twh_221109_gcode')
     while True:
-        g_amq.process_data_events()
+        g_amq.process_data_events(0.1)
         a.spin_once()
 
     # s =  AmqMqtt_Bridge('twh_221109_gcode', 'twh/221109/gcode_feed')
